# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('newsletter', '__first__'),
        ('newsletter_extension', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='ErrorMessage',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('message', models.CharField(max_length=2048, null=True, blank=True)),
                ('contact', models.ForeignKey(verbose_name='contact', to='newsletter.Contact',on_delete=models.CASCADE)),
                ('newsletter', models.ForeignKey(verbose_name='newsletter', to='newsletter.Newsletter',on_delete=models.CASCADE)),
            ],
        ),
    ]
